@@ -6,7 +6,7 @@ use Moose::Util::MetaRole;
 
 use DBIx::Class::MooseColumns::Meta::Attribute;
 
-Moose::Exporter->setup_import_methods( also => 'Moose' );
+Moose::Exporter->setup_import_methods();
 
 sub init_meta {
   my ($class, %args) = (shift, @_);
@@ -30,11 +30,11 @@ DBIx::Class::MooseColumns - Lets you write DBIC add_column() definitions as attr
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 
 =head1 SYNOPSIS
