@@ -9,6 +9,8 @@ use DBIx::Class::MooseColumns;
 
 extends 'DBIx::Class::Core';
 
+__PACKAGE__->load_components(qw/InflateColumn::DateTime/);
+
 __PACKAGE__->table('artist');
 
 # used for testing if ->add_column() works (also PK so used to find the row)
@@ -38,6 +40,15 @@ has title => (
   },
 );
 
+# used for InflateColumn tests
+has birthday => (
+  isa => 'Str',
+  is  => 'rw',
+  add_column => {
+    data_type => 'date',
+  },
+);
+
 # used for benchmarking (CAG accessor)
 has address => (
   isa => 'Str',
